/* @fwrlines/generator-react-component 2.3.4 */
import * as React from 'react'
import { useMemo, useContext } from 'react'
import PropTypes from 'prop-types'
import { Link } from 'react-router-dom'
import { useIsTop } from '@fwrlines/utils'
import { ThemeSelector, NavBar, Button, SiteContext } from '@fwrlines/ds'

import * as URLS from 'app/urls'

import NavMap from '../../NavMap'
//Intl

//import { FormattedMessage} from "react-intl";
//import messages from "./messages";
// <FormattedMessage {...messages.title} />

//Config

//import C from 'ui/cssClasses'

//Relative imports
//import styles from './local_nav_bar.scss'
/*
import { isBackend } from 'utils/isBackend'

if (!isBackend) {
  import('./local_nav_bar.scss')
}
*/

const baseClassName = 'local_nav_bar'


/**
 * Use `LocalNavBar` to
 * Has color `x`
 */
const LocalNavBar = ({
  id,
  className,
  style,
  title,
  min,
  ...otherProps
}) => {
  const isTop = useIsTop()
  
  const {
    SITE_NAME,
    HOME_URL
  } = useContext(SiteContext)


  const TitleComponent = useMemo(() => ({ open }) => (
    <Link
      to={HOME_URL}
      className={[
        (min && !open) && 'xs-h sm-h'
      ].filter(e => e).join(' ')}
    >
      <span
        className="v0 mv-v h3 u1 ph-u xs-h sm-h"
        style={{ whiteSpace: 'nowrap' }}
      >
        { title || SITE_NAME }
      </span>
      <span
        className="v0 mv-v h3 u50 ph-u md-h lg-h"
        style={{ whiteSpace: 'nowrap' }}
      >
        { SITE_NAME }
      </span>
    </Link>


  ), [])

  const FooterComponent = useMemo(() => ({ open }) => (
    <Button.Group className={
      [
        (!open && min) && 'xs-h sm-h',
        open && 'v1 p-v',
        'i-footer u1 sm-u50 pr-u'
      ].filter(e => e).join(' ')
    }
    >
      <ThemeSelector
        simple
        className={
          [
            open ? 's2 k-s' : 's1 k-s',
            'x-link'
          ].filter(e => e).join(' ')
        }
      />
    </Button.Group>


  ), [])
  
  
  return (
    <NavBar
      className={
        [
          //styles[baseClassName],
          baseClassName,
          'b-light-y',
          className
        ].filter(e => e).join(' ')
      }
      openClassName="y-background u50 p-u"
      closedClassName={
        [
          isTop ? 'istop y-transparent' : 'y-background style1'
        ].filter(e => e).join(' ')

      }
      id={id}
      style={{
        ...style,
        minHeight:'3em',
        zIndex   :'2'
      }}
      headerClassName="x-paragraph"
      headerOpenClassName="x-link s1 k-s"
      headerClosedClassName="x-link"
      contentOpenClassName="s3 k-s u1 ph-u v1 pv-v"
      contentClosedClassName="s1 k-s v1 pv-v pr-v"
      FooterComponent={FooterComponent}
      TitleComponent={TitleComponent}
      {...otherProps}
    >
      { NavMap.map(({ to, ...props }, i) =>
        (
          <NavBar.Item
            link={to}
            {...props}
            key={i}
          />
        )
      ) }
    </NavBar>
  )
}

LocalNavBar.propTypes = {

  /**
   * Provide an HTML id to this element
   */
  id:PropTypes.string,

  /**
   * The html class names to be provided to this element
   */
  className:PropTypes.string,

  /**
   * The JSX-Written, css styles to apply to the element.
   */
  style:PropTypes.object,

  /**
   *  The children JSX
   */
  children:PropTypes.node,

  /**
   * Which html tag to use
   */
  as:PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.object
  ]),
  //as: PropTypes.string,

  /**
   * The height of the element
   */
  height:PropTypes.string,

  /**
   * The width of the element
   */
  width:PropTypes.string

  /*
  : PropTypes.shape({
    id: PropTypes.string.isRequired,
    title: PropTypes.string.isRequired,
    state: PropTypes.string.isRequired,
  }),
  : PropTypes.func,
  : PropTypes.func,
  : PropTypes.oneOf(['', ''])
  */
}

/*
LocalNavBar.defaultProps = {
  status: 'neutral',
  //height:'2.2em',
  //as:'p',
}
*/
export default LocalNavBar
